@@ -25,12 +25,15 @@ class InfoBaseClass(abc.ABC):
         return f"{self.__class__.__name__}({self.id!r})"
 
     def __eq__(self, other: Any) -> bool:
-        if isinstance(other, str):
-            return self.id == str(other)
-        if isinstance(other, int):
-            return self.id == int(str(other))
-        return False
-
+        if not isinstance(other, (int, str, InfoBaseClass)):
+            return NotImplemented
+        if isinstance(other, Mouse):
+            return self.id == other.id
+        return str(self) == str(other) or str(self.id) == str(other)
+    
+    def __hash__(self) -> int:
+        return hash(self.id) ^ hash(self.__class__.__name__)
+    
 
 class Mouse(InfoBaseClass):
     def __init__(self, labtracks_mouse_id: str | int):
