@@ -244,13 +244,14 @@ class PlatformJson(pydantic.BaseModel):
         with contextlib.suppress(TypeError, AttributeError):
             new = np_config.merge(copy.deepcopy(getattr(self, field)), new)
             
-        print('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
+        logger.debug('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
         setattr(self, field, new)
     
 def update_from_session(pj: PlatformJson, session) -> None:
     "Updates fields in a platform json file."
     
     with pj.sync_disabled():
+        logger.debug("Updating %s with session %s fields, with write disabled", pj.path.name, session.id)
         pj.update('operatorID', str(session.user)) # don't need to convert here, `update` will compare values with existing
         pj.update('sessionID', str(session.id))
         pj.update('mouseID', str(session.mouse.id))
